@@ -152,7 +152,7 @@ def get_mask_of_samples(image_shape: Tuple[int, int], row_grid: np.ndarray, colu
     return mask
 
 
-class BaseSamplingTask(EOTask, metaclass=ABCMeta):
+class BaseSamplingTask(EOTask, metaclass=ABCMeta):  # noqa: B024
     """A base class for sampling tasks"""
 
     def __init__(self, features_to_sample, *, mask_of_samples=None):
